@@ -1,4 +1,5 @@
 import os
+import sys
 from pathlib import Path
 from typing import List, Union
 
@@ -34,7 +35,7 @@ def export(
         )
 
     if not destdir.exists():
-        print(f"Creating {destdir}/")
+        print(f"Creating {destdir}/", file=sys.stderr)
         destdir.mkdir()
 
     copy_fn = _utils.create_copy_fn(overwrite=False, verbose_print=verbose_print)
@@ -45,7 +46,10 @@ def export(
     # Copy the base dependencies for shinylive/ distribution. This does not include the
     # Python package files.
     # =========================================================================
-    print(f"Copying base Shinylive files from {assets_dir}/ to {destdir}/")
+    print(
+        f"Copying base Shinylive files from {assets_dir}/ to {destdir}/",
+        file=sys.stderr,
+    )
     base_files = _deps.shinylive_common_files()
     for file in base_files:
         src_path = assets_dir / file
@@ -83,7 +87,8 @@ def export(
         package_files: List[str] = [dep["file_name"] for dep in deps]
 
         print(
-            f"Copying imported packages from {assets_dir}/shinylive/pyodide/ to {destdir}/shinylive/pyodide/"
+            f"Copying imported packages from {assets_dir}/shinylive/pyodide/ to {destdir}/shinylive/pyodide/",
+            file=sys.stderr,
         )
         verbose_print(" ", ", ".join(package_files))
 
@@ -106,5 +111,6 @@ def export(
     )
 
     print(
-        f"\nRun the following to serve the app:\n  python3 -m http.server --directory {destdir} 8008"
+        f"\nRun the following to serve the app:\n  python3 -m http.server --directory {destdir} 8008",
+        file=sys.stderr,
     )
